@@ -29,17 +29,9 @@ extern int player_display;
 
 void display_player();
 void display_playertitle();
-void display_time(int mins, int secs, int rms, int rss);
+void display_time(int mins, int secs, int rms, int rss, int bitrate);
 void display_status();
 void display_song();
-int play_pause();
-int stop();
-int fforward();
-int frewind();
-int next_file();
-int prev_file();
-int repeat_mode();
-int time_data();
-int toggle_pm();
 
 #endif
+
