@@ -27,9 +27,7 @@
 extern int playlist_display;
 
 void display_playlist();
-void display_playlisttitle();
 void display_list();
-void reinit_playlistcursor();
 
 int previous();
 int next();
@@ -44,6 +42,8 @@ int sel_all();
 int unsel_all();
 int invert_sel();
 int move_entry();
+int get_cursor();
+void set_cursor(int new_pos);
 
 #endif
 
