@@ -24,32 +24,59 @@
 #define TMMS_H
 
 #include <pthread.h>
+#include "terminal.h"
 
-/* Access to current entry */
-pthread_mutex_t mutex_current;
+#define CHECK_DISPLAY(auth) \
+        if (! auth) \
+        { \
+                return; \
+        }
 
-/* Requests and Status */
-pthread_mutex_t mutex_request;
-pthread_mutex_t mutex_status;
-
-/* Display operations */
-pthread_mutex_t mutex_display;
-
-
-#define COLORIZED
+#define DEFAULT_CFGFILE ".tmmsrc"
 
 typedef enum {NOTHING, PLAYING, PAUSED, STOPPED, FFW, RWD, NEXT, PREV} Status;
-typedef enum {REPEAT_NUL, REPEAT_ONE, REPEAT_ALL} Mode;
-typedef enum {NORMAL, REMAIN} TimeData;
+typedef enum {REPEAT_NOT, REPEAT_ONE, REPEAT_ALL} Mode;
+typedef enum {ELAPSED, REMAINING} TimeData;
+
+/* Elements to be colorized */
+typedef enum {
+        NormalColor = 0,
+        BordersColor,
+        WindowTitleColor,
+        TimeColor,
+        BitrateColor,
+        StatusColor,
+        PlayedSongColor,
+        NumberColor,
+        MoveCursorColor,
+        SelectedColor,
+        ListSongColor,
+        NB_COLOR_ELEMENTS
+} ColorElement;
 
 
-TimeData  timedata;
-char     *all_locale;
+/** GLOBAL VARIABLES */
+/* Access to current entry */
+extern pthread_mutex_t mutex_current;
+
+/* Requests and Status */
+extern pthread_mutex_t mutex_request;
+extern pthread_mutex_t mutex_status;
+
+/* Display operations */
+extern pthread_mutex_t mutex_display;
+
+/* Other global variables */
+extern TimeData        timedata;
+extern Mode            repeat_mode;
+extern char          * output_device;
 
 
+char *robust_home(const char *user);
 int redisp();
 int quit();
 int reload_list();
 
 
 #endif
+
