@@ -27,21 +27,31 @@
 #include "xmem.h"
 
 
-void *xmalloc(size_t size) {
-    void *ret = malloc(size);
-    if (! ret) {
-        perror("malloc() ");
-        exit(-1);
-    } else
-        return ret;
+void *xmalloc(size_t size)
+{
+        void *ret = malloc(size);
+        if (! ret)
+        {
+                perror("malloc() ");
+                exit(-1);
+        }
+        else
+        {
+                return ret;
+        }
 }
 
 
-char *xstrdup(const char *string) {
-    char *ret = strdup(string);
-    if (! ret) {
-        perror("strdup() ");
-        exit(-1);
-    } else
-        return ret;
+char *xstrdup(const char *string)
+{
+        char *ret = strdup(string);
+        if (! ret)
+        {
+                perror("strdup() ");
+                exit(-1);
+        }
+        else
+        {
+                return ret;
+        }
 }
